import { useRef } from 'react';
import { useLoad, useUnload, useAppActive, useAppInactive, } from 'react-native-lifecycle';
/**
 * App 定时器，App 活跃时激活，App 后台运行时停止
 * @param {function} effect 事件
 * @param {number} ms 毫秒
 * @param {object} options
 * @param {boolean} options.enabled 是否激活 default true
 * @public
 */
export default (effect, ms, options = {}) => {
    const { enabled = true } = options;
    const i = useRef(null);
    const appActive = useRef(true);
    const isEnabled = useRef(enabled);
    useAppActive(() => {
        appActive.current = true;
    });
    useAppInactive(() => {
        appActive.current = false;
    });
    useLoad(() => {
        i.current = setInterval(() => {
            if (appActive.current && isEnabled.current) {
                effect();
            }
        }, ms);
    });
    useUnload(() => {
        if (i.current) {
            clearInterval(i.current);
        }
    });
    const setEnabled = (enabled) => {
        isEnabled.current = enabled;
    };
    return {
        setEnabled,
    };
};
