import { useRef } from 'react';
import { useLoad, useUnload } from 'react-native-lifecycle';
/**
 * 页面定时器，页面释放时释放
 * @param {function} effect
 * @param {number} ms 毫秒 default RESULTS.GRANTED
 * @param {object} options
 * @param {boolean} options.enabled 是否激活 default true
 * @public
 */
export default (effect, ms, options = {}) => {
    const { enabled = true } = options;
    const i = useRef(null);
    const isEnabled = useRef(enabled);
    useLoad(() => {
        i.current = setInterval(() => {
            if (isEnabled.current) {
                effect();
            }
        }, ms);
    });
    useUnload(() => {
        if (i.current) {
            clearInterval(i.current);
        }
    });
    const setEnabled = (enabled) => {
        isEnabled.current = enabled;
    };
    return {
        setEnabled,
    };
};
